@@ -38,8 +38,9 @@ import os
 
 # Internal module convenience imports
 from .py4cytoscape_utils import *
-from .py4cytoscape_logger import cy_log, log_http_result, log_http_request
-from .py4cytoscape_notebook import running_remote, do_request_remote, check_running_remote
+from .py4cytoscape_logger import cy_log, log_http_result, log_http_request, show_error
+from .py4cytoscape_notebook import running_remote, do_request_remote, check_running_remote, get_notebook_is_running
+from .py4cytoscape_sandbox import *
 from .exceptions import CyError
 
 
@@ -58,7 +59,7 @@ def cyrest_api(base_url=DEFAULT_BASE_URL):
 
     Args:
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -83,7 +84,7 @@ def cyrest_delete(operation=None, parameters=None, base_url=DEFAULT_BASE_URL, re
         operation (str): A string to be converted to the REST query namespace
         parameters (dict): A named list of values to be converted to REST query parameters
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
         require_json (bool): True if only JSON is accepted as a response; otherwise, return non-JSON if response is non-JSON
 
@@ -102,7 +103,7 @@ def cyrest_delete(operation=None, parameters=None, base_url=DEFAULT_BASE_URL, re
     """
     try:
         url = build_url(base_url, operation)
-        r = _do_request('DELETE', url, params=parameters)
+        r = _do_request('DELETE', url, params=parameters, base_url=base_url)
         r.raise_for_status()
         try:
             return r.json()
@@ -123,7 +124,7 @@ def cyrest_get(operation=None, parameters=None, base_url=DEFAULT_BASE_URL, requi
         operation (str): A string to be converted to the REST query namespace
         parameters (dict): A named list of values to be converted to REST query parameters
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
         require_json (bool): True if only JSON is accepted as a response; otherwise, return non-JSON if response is non-JSON
 
@@ -142,7 +143,7 @@ def cyrest_get(operation=None, parameters=None, base_url=DEFAULT_BASE_URL, requi
     """
     try:
         url = build_url(base_url, operation)
-        r = _do_request('GET', url, params=parameters)
+        r = _do_request('GET', url, params=parameters, base_url=base_url)
         r.raise_for_status()
         try:
             return r.json()
@@ -164,7 +165,7 @@ def cyrest_post(operation=None, parameters=None, body=None, base_url=DEFAULT_BAS
         parameters (dict): A named list of values to be converted to REST query parameters
         body (dict): A named list of values to be converted to JSON
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
         require_json (bool): True if only JSON is accepted as a response; otherwise, return non-JSON if response is non-JSON
 
@@ -183,7 +184,7 @@ def cyrest_post(operation=None, parameters=None, body=None, base_url=DEFAULT_BAS
     """
     try:
         url = build_url(base_url, operation)
-        r = _do_request('POST', url, params=parameters, json=body, headers = {'Content-Type': 'application/json'})
+        r = _do_request('POST', url, params=parameters, json=body, headers = {'Content-Type': 'application/json'}, base_url=base_url)
         r.raise_for_status()
         try:
             return r.json()
@@ -205,7 +206,7 @@ def cyrest_put(operation=None, parameters=None, body=None, base_url=DEFAULT_BASE
         parameters (dict): A named list of values to be converted to REST query parameters
         body (dict): A named list of values to be converted to JSON
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
         require_json (bool): True if only JSON is accepted as a response; otherwise, return non-JSON if response is non-JSON
 
@@ -222,7 +223,7 @@ def cyrest_put(operation=None, parameters=None, body=None, base_url=DEFAULT_BASE
     """
     try:
         url = build_url(base_url, operation)
-        r = _do_request('PUT', url, params=parameters, json=body, headers = {'Content-Type': 'application/json'})
+        r = _do_request('PUT', url, params=parameters, json=body, headers = {'Content-Type': 'application/json'}, base_url=base_url)
         r.raise_for_status()
         try:
             return r.json()
@@ -247,7 +248,7 @@ def commands_api(base_url=DEFAULT_BASE_URL):
 
     Args:
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -274,7 +275,7 @@ def commands_get(cmd_string, base_url=DEFAULT_BASE_URL):
     Args:
         cmd_string (str): command
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -294,7 +295,7 @@ def commands_get(cmd_string, base_url=DEFAULT_BASE_URL):
     """
     try:
         get_url, parameters = _command_2_get_query(cmd_string, base_url=base_url)
-        r = _do_request('GET', get_url, params=parameters, headers={'Accept': 'text/plain'})
+        r = _do_request('GET', get_url, params=parameters, headers={'Accept': 'text/plain'}, base_url=base_url)
         r.raise_for_status()
 
         # Break response into a list of lines and return it
@@ -319,7 +320,7 @@ def commands_help(cmd_string='help', base_url=DEFAULT_BASE_URL):
     Args:
         cmd_string (str): command
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -336,7 +337,7 @@ def commands_help(cmd_string='help', base_url=DEFAULT_BASE_URL):
     try:
         cmd_string = re.sub(r'help *', cmd_string, cmd_string)  # remove 'help ' if it's already in the request
         get_url, parameters = _command_2_get_query(cmd_string, base_url=base_url)
-        r = _do_request('GET', get_url, params=parameters, headers={'Accept': 'text/plain'})
+        r = _do_request('GET', get_url, params=parameters, headers={'Accept': 'text/plain'}, base_url=base_url)
         r.raise_for_status()
 
         # Break response into a list of lines and return it
@@ -359,7 +360,7 @@ def commands_post(cmd, base_url=DEFAULT_BASE_URL):
     Args:
         cmd_string (str): command
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -381,7 +382,7 @@ def commands_post(cmd, base_url=DEFAULT_BASE_URL):
         post_url = _command_2_post_query_url(cmd, base_url=base_url)
         post_body = _command_2_post_query_body(cmd)
         headers = {'Content-Type': 'application/json', 'Accept': 'application/json'}
-        r = _do_request('POST', post_url, json=post_body, headers=headers)
+        r = _do_request('POST', post_url, json=post_body, headers=headers, base_url=base_url)
         r.raise_for_status()
         return json.loads(r.text)['data']
     except requests.exceptions.RequestException as e:
@@ -398,7 +399,7 @@ def commands_run(cmd_string, base_url=DEFAULT_BASE_URL):
     Args:
         cmd_string (str): command
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -426,7 +427,7 @@ def command_echo(variable_name='*', base_url=DEFAULT_BASE_URL):
     Args:
         variable_name (str): The name of the variable to display. Default is to display all variable values using "*".
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -454,7 +455,7 @@ def command_open_dialog(base_url=DEFAULT_BASE_URL):
 
     Args:
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -478,7 +479,7 @@ def command_pause(message='', base_url=DEFAULT_BASE_URL):
     Args:
         message (str): Text to display in pause dialog
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -502,7 +503,7 @@ def command_quit(base_url=DEFAULT_BASE_URL):
 
     Args:
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -528,7 +529,7 @@ def command_run_file(file, args=None, base_url=DEFAULT_BASE_URL):
 
     Args:
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -542,8 +543,7 @@ def command_run_file(file, args=None, base_url=DEFAULT_BASE_URL):
         {}
     """
     args_str = f' args="{args}"' if args else ''
-    if not running_remote():
-        file = os.path.abspath(file)
+    file = get_abs_sandbox_path(file)
 
     return commands_post(f'command run{args_str} file="{file}"', base_url=base_url)
 
@@ -558,7 +558,7 @@ def command_sleep(duration=None, base_url=DEFAULT_BASE_URL):
     Args:
         duration (float): The time in seconds to sleep
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -647,55 +647,130 @@ def _command_2_post_query_body(cmd):
 
     return param_dict
 
-
-def prep_post_query_lists(cmd_list=None, cmd_by_col=None):
-    if cmd_list is None:
-        cmd_list_ready = 'selected'
-    elif not cmd_by_col is None:
-        cmd_list_col = [cmd_by_col + ':' + cmd for cmd in cmd_list]
-        cmd_list_ready = ','.join(cmd_list_col)
+def sub_versions(base_url=DEFAULT_BASE_URL, **kwargs):
+    # If we're running through Jupyter-Bridge, get the versions of components along the way
+    if _find_remote_cytoscape():
+        return do_request_remote('version', None, **kwargs).json()
     else:
-        cmd_list_ready = cmd_list if isinstance(cmd_list, str) else ','.join(cmd_list)
-
-    return cmd_list_ready
-
+        return {}
 
 def _handle_error(e, force_cy_error=False):
+    # An exception occurred ... figure out the most sensible thing to return as the exception text
     caller = sys._getframe(1).f_code.co_name
     if e.response is None or e.response.text is None or e.response.text == '':
-        narrate(f'In {caller}: {e}')
+        show_error(f'In {caller}: {e}') # Was: narrate(f'In {caller}: {e}')
         raise
     else:
         content = e.response.text
         try:
             content = json.loads(content)['errors'][0]['message']
-            narrate(f'In {caller}: {e}\n{content}')
+# now written to stderrr by CyError constructor:            narrate(f'In {caller}: {e}\n{content}')
             e = CyError(content, caller=caller)
         except:
-            narrate(f'In {caller}: {e}\n{content}')
-            if force_cy_error: e = CyError(content, caller=caller)
+# now written to stderrr by CyError constructor:            narrate(f'In {caller}: {e}\n{content}')
+            if force_cy_error:
+                e = CyError(content, caller=caller)
+            else:
+                show_error(f'In {caller}: {e}\n{content}')
         raise e
 
-# Call CyREST via a local URL
+
 def _do_request_local(method, url, **kwargs):
+    # Call CyREST via a local URL
     log_http_request(method, url, **kwargs)
     r = requests.request(method, url, **kwargs)
     log_http_result(r)
     return r
 
-# Determine whether actual call is local or remote
-def _do_request(method, url, **kwargs):
-    remote_cytoscape = check_running_remote()
-    if remote_cytoscape is None:
-        raise requests.exceptions.RequestException('Cannot find local or remote Cytoscape. Start Cytoscape and then proceed.')
-    requester = do_request_remote if running_remote() else _do_request_local
+def _do_request(method, url, base_url=DEFAULT_BASE_URL, **kwargs):
+    # Determine whether actual call is local or remote
+    requester = _get_requester()
+
+    do_initialize_sandbox(requester, base_url=base_url) # make sure there's a sandbox before executing a command
+
     return requester(method, url, **kwargs)
 
+def do_initialize_sandbox(requester=None, base_url=DEFAULT_BASE_URL):
+    # If re-initialize has been requested, reset sandbox to environment's default (i.e., None or default_sandbox)
+    if get_sandbox_reinitialize():
+        return do_set_sandbox(_get_default_sandbox(), requester, base_url=base_url)
+    else:
+        return get_current_sandbox()
+
+def do_set_sandbox(sandbox_to_set, requester=None, base_url=DEFAULT_BASE_URL):
+    # Set the sandbox to whatever is passed in. Note that sandbox_to_set is a dictionary not a string.
+    requester = requester or _get_requester()
+    if not sandbox_to_set['sandboxName']:
+        # A null name means that the default sandbox should be used, but honoring the copySamples and reinitialize
+        # settings passed in by the caller.
+        sandbox_to_set['sandboxName'] = _get_default_sandbox()['sandboxName']
+    sandbox_name = sandbox_to_set['sandboxName']
+    if sandbox_name:
+        # A named sandbox name means to create one if it doesn't already exist ... otherwise, preserve it and apply
+        # copySamples or reinitialize if true
+        try:
+            r = requester('POST', f'{base_url}/commands/filetransfer/setSandbox',
+                          json=sandbox_to_set,
+                          headers={'Content-Type': 'application/json', 'Accept': 'application/json'})
+            r.raise_for_status()
+            new_sandbox = set_current_sandbox(sandbox_name, json.loads(r.text)['data']['sandboxPath'])
+        except Exception as e:
+            raise CyError(f'Error: FileTransfer app must be installed in Cytoscape: {e}')
+    else:
+        # A null name really means to use the whole Cytoscape file system. If the default sandbox is set up right,
+        # we should never get here if we're running a notebook or remote configuration.
+        #
+        # Either way, we consider the Cytoscape installation directory to be the sandbox because that's what the
+        # Cytoscape current directory is when Cytoscape executes ... the same place an unqualified file name would
+        # resolve to if Cytoscape were to be saving a file. For the sake of testing and consistency, we need to
+        # find out what that path is and return it as part of the sandbox descriptor.
+        default_sandbox_path = get_default_sandbox_path()
+        if default_sandbox_path is None:
+            try:
+                r = requester('POST', f'{base_url}/commands/filetransfer/getFileInfo',
+                              json={'sandboxName': None, 'fileName': '.'},
+                              headers={'Content-Type': 'application/json', 'Accept': 'application/json'})
+                r.raise_for_status()
+                default_sandbox_path = set_default_sandbox_path(json.loads(r.text)['data']['filePath'])
+            except Exception as e:
+                # This is a nasty case ... it's hard for getFileInfo to fail unless FileTransfer isn't installed.
+                # We'll assume that's so, and assume that means we're running on the Cytoscape workstation. So,
+                # coerce the paths to be consistent with that situation. Sandbox functions will fail, but
+                # functions that depend only on calculating paths should do fine.
+                default_sandbox_path = None
+                narrate('Warning: FileTransfer app is not available, so sandbox operations will fail')
+        new_sandbox = set_current_sandbox(None, default_sandbox_path)
+
+    set_sandbox_reinitialize(False) # No need to initialize again immediately before the next command is issued
+    return new_sandbox
+
+def _get_default_sandbox():
+    # Figure out what the default sandbox be, depending on whether a Notebook is running or we're on the Cytoscape workstation
+    default = get_default_sandbox()
+    if len(default) == 0:
+        # There hasn't been a default sandbox calculated yet ... create a new default to reflect Notebook and remote
+        # execution. This determination is deferred until now (instead of occurring when Python execution first starts)
+        # so as to give the user some flexibility regarding when Cytoscape needs to be started ... this allows
+        # Cytoscape to be started only before the user issues the first command.
+        if get_notebook_is_running() or running_remote():
+            default = sandbox_initializer(sandboxName=PREDEFINED_SANDBOX_NAME)
+        else:
+            default = sandbox_initializer(sandboxName=None)  # for local execution not under a Notebook
+        set_default_sandbox(**default)
+    return default
+
+def _get_requester():
+    # Figure out whether CyREST is local or remote ... if remote, we'll want to go through Jupyter-Bridge
+    return do_request_remote if _find_remote_cytoscape() else _do_request_local
+
 def _do_browser_open(url, **kwargs):
-    remote_cytoscape = check_running_remote()
-    if remote_cytoscape is None:
-        raise requests.exceptions.RequestException('Cannot find local or remote Cytoscape. Start Cytoscape and then proceed.')
-    if running_remote():
+    # Figure out whether CyREST is local or remote ... if remote, issue a browser command through Jupyter-Bridge
+    if _find_remote_cytoscape():
         return do_request_remote('webbrowser', url, **kwargs)
     else:
         return webbrowser.open(url, new=2, autoraise=True)
+
+def _find_remote_cytoscape():
+    if check_running_remote() is None:
+        raise requests.exceptions.RequestException('Cannot find local or remote Cytoscape. Start Cytoscape and then proceed.')
+    return running_remote()
\ No newline at end of file
