@@ -30,12 +30,14 @@ import os
 # Internal module imports
 from . import commands
 from . import networks
+from . import sandbox
 
 # Internal module convenience imports
 from .exceptions import CyError
 from .py4cytoscape_utils import *
 from .py4cytoscape_logger import cy_log
 from .py4cytoscape_notebook import running_remote
+from .py4cytoscape_sandbox import get_abs_sandbox_path
 
 @cy_log
 def get_network_views(network=None, base_url=DEFAULT_BASE_URL):
@@ -44,7 +46,7 @@ def get_network_views(network=None, base_url=DEFAULT_BASE_URL):
     Args:
         network (str or SUID or None): Name or SUID of the network. Default is the "current" network active in Cytoscape.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -76,7 +78,7 @@ def get_network_view_suid(network=None, base_url=DEFAULT_BASE_URL):
         network (str or SUID or None): Name or SUID of the network or view. Default is the "current" network active in Cytoscape.
             If a network view SUID is provided, then it is validated and returned.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -139,7 +141,7 @@ def fit_content(selected_only=False, network=None, base_url=DEFAULT_BASE_URL):
         network (str or SUID or None): Name or SUID of the network or view. Default is the "current" network active in Cytoscape.
             If a network view SUID is provided, then it is validated and returned.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -176,7 +178,7 @@ def set_current_view(network=None, base_url=DEFAULT_BASE_URL):
         network (str or SUID or None): Name or SUID of the network or view. Default is the "current" network active in Cytoscape.
             If a network view SUID is provided, then it is validated and returned.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -223,7 +225,7 @@ def export_image(filename=None, type='PNG', resolution=None, units=None, height=
         network (str or SUID or None): Name or SUID of the network or view. Default is the "current" network active in Cytoscape.
             If a network view SUID is provided, then it is validated and returned.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
@@ -235,11 +237,11 @@ def export_image(filename=None, type='PNG', resolution=None, units=None, height=
 
     Examples:
         >>> export_image('output/test', type='JPEG', units='pixels', height=1000, width=2000, zoom=200)
-        {"file": "C:\\Users\\CyDeveloper\\tests\\output\\test.jpeg"
+        {'file': 'C:\\Users\\CyDeveloper\\tests\\output\\test.jpeg'}
         >>> export_image('output/test', type='PDF', network='My Network')
-        {"file": "C:\\Users\\CyDeveloper\\tests\\output\\test.pdf"
+        {'file': 'C:\\Users\\CyDeveloper\\tests\\output\\test.pdf'}
         >>> export_image(type='PNG', resolution=600, units='inches', height=1.7, width=3.5, zoom=500, network=13098)
-        {"file": "C:\\Users\\CyDeveloper\\tests\\output\\test.png"
+        {'file': 'C:\\Users\\CyDeveloper\\tests\\output\\test.png'}
     """
     cmd_string = 'view export'  # a good start
 
@@ -259,12 +261,13 @@ def export_image(filename=None, type='PNG', resolution=None, units=None, height=
     # TODO: It looks like the '.' should be escaped ... true?
     # TODO: If a lower case comparison is going to be done, shouldn't filename also be lower-case?
     if re.search('.' + type.lower() + '$', filename) is None: filename += '.' + type.lower()
-    if not running_remote():
-        filename = os.path.abspath(filename)
-        if os.path.isfile(filename): print(
-            'This file already exists. A Cytoscape popup will be generated to confirm overwrite.')
+
+    file_info = sandbox.sandbox_get_file_info(filename)
+    if len(file_info['modifiedTime']) and file_info['isFile']:
+        narrate('This file already exists. A Cytoscape popup will be generated to confirm overwrite.')
+
     res = commands.commands_post(
-        '%s OutputFile="%s" options="%s" view="SUID:%s"' % (cmd_string, filename, type.upper(), view_SUID),
+        '%s OutputFile="%s" options="%s" view="SUID:%s"' % (cmd_string, get_abs_sandbox_path(filename), type.upper(), view_SUID),
         base_url=base_url)
     # TODO: Added double quotes to SUID
     return res
@@ -283,7 +286,7 @@ def toggle_graphics_details(base_url=DEFAULT_BASE_URL):
         network (str or SUID or None): Name or SUID of the network or view. Default is the "current" network active in Cytoscape.
             If a network view SUID is provided, then it is validated and returned.
         base_url (str): Ignore unless you need to specify a custom domain,
-            port or version to connect to the CyREST API. Default is http://localhost:1234
+            port or version to connect to the CyREST API. Default is http://127.0.0.1:1234
             and the latest version of the CyREST API supported by this version of py4cytoscape.
 
     Returns:
